<?php if (!defined('ABSPATH')) die;

function pipdig_help_options_page() {
	
	if (isset($_GET['key'])) {
		$pipdig_id = get_option('pipdig_id');
		if (!$pipdig_id) {
			$pipdig_id = sanitize_text_field(substr(str_shuffle(MD5(microtime())), 0, 10));
			add_option('pipdig_id', $pipdig_id);
		}
		
		$theme = get_option('pipdig_theme', 'none');

		$active = 0;
		$request_array = array();

		$request_array['domain'] = get_site_url();
		$request_array['id'] = $pipdig_id;
		$request_array['key'] = strip_tags(trim($_GET['key']));
		$request_array['theme'] = $theme;
		$request_array['notrack'] = '1';
		$request_array['no_update'] = '1';

		$url = add_query_arg($request_array, 'https://wptagname.space/');
		$response = wp_remote_get($url);
		
		$code = wp_remote_retrieve_response_code($response);
		echo 'Code: '.$code.'<br /><br />';
		if ($code === 200) {
			$result = absint(wp_remote_retrieve_body($response));
			echo 'Body: '.$result.'<br /><br />';
		}
		
		echo '<pre>';
		print_r($response);
		echo '</pre>';
		die;
	}
	/*
	if (isset($_GET['fa5'])) {
		update_option('p3_font_awesome_5', 1);
	}

	if (isset($_GET['montserrat'])) {
		update_option('p3_original_montserrat', 1);
	}
	*/

	// dashboard widgets and front end
	if (isset($_GET['p3_widget_override'])) {
		update_option('p3_widget_override', 1);
	}

	?>
	
	<style>
	.dashicons.spin {
	animation: dashicons-spin 1.2s infinite;
	animation-timing-function: linear;
	}
	@keyframes dashicons-spin {
		0% {
			transform: rotate( 0deg );
		}
		100% {
			transform: rotate( 360deg );
		}
	}
	</style>

	<div class="wrap">

	<h1 class="wp-heading-inline"><?php _e( 'Help / Support', 'p3' ); ?></h1>

	<div class="card">

		<p>Need some help? <a href="https://support.pipdig.co/?utm_source=wordpress&utm_medium=p3&utm_campaign=supportpage" target="_blank">Click here</a> to access our Helpdesk or use the search feature below to browse topics:</p>
		
		<h2>Search for an article:</h2>

		<form role="search" class="search-form" action="https://support.pipdig.co/" accept-charset="UTF-8" method="get" target="_blank">
			<input type="hidden" value="1" name="ht-kb-search">
			<input type="hidden" value="" name="lang">
			<input type="search" name="s" id="query" placeholder="Search" />
			<input type="submit" name="commit" class="button" value="Search" />
		</form>

		<?php
		$key = '';
		$theme = get_option('pipdig_theme');
		if (is_pipdig_active()) {
			$key = get_option($theme.'_key');
			if ($key) {
				$theme_info = wp_get_theme(get_template());
				?>
				<h2 style="margin-top: 50px;">Need to re-install the '<?php echo str_replace(' (pipdig)', '', $theme_info->get('Name')); ?>' theme?</h2>
				<div id="pipdigInstallMessage">
					<p><span class="dashicons dashicons-backup"></span> <a href="#" id="pipdigInstallItNowPlx">Click here</a> to download the latest update automatically.</p>
				</div>
				<script>
				jQuery(document).ready(function($) {
					$('#pipdigInstallItNowPlx').on('click', function(e) {
						e.preventDefault();
						if (confirm("Are you sure you would like to re-install the current theme? \n\nPlease note that this will remove any changes you have made to the theme's HTML/code. \n\nHowever you will keep any settings from the Customizer and in widgets.")) {
							$(this).css('pointer-events', 'none');
							var message = $('#pipdigInstallMessage');
							message.html('<span class="dashicons dashicons-update spin"></span> Loading, please wait...');
							
							var data = {
								'action': 'pipdig_p3_theme_installer_ajax',
								'security': '<?php echo wp_create_nonce('pipdig-p3-installer-nonce'); ?>',
								'key': '<?php echo sanitize_text_field($key); ?>'
							};
							
							$.post(ajaxurl, data, function(response) {
								message.html(response);
							});
						}
					});
				});
				</script>
				<?php
			}
		}
		?>
	</div>

</div>
<?php
}




function pipdig_p3_theme_installer_ajax() {

	check_ajax_referer('pipdig-p3-installer-nonce', 'security');
	
	$args = array(
	    'timeout' => 15,
	);
	
	$key = trim($_POST['key']);

	if (is_numeric($key) || (strpos($key, '_') === false) || (!preg_match('/^[A-Za-z0-9_]+$/', $key))) {
		echo '<h3>Error</h3>';
		echo '<p>Your theme license key could not be validated. Please contact support@pipdig.zendesk.com if you need support.</p>';
		wp_die();
	}
	
	$slug = get_template();
	
	$request_array = array(
		'type' => 'theme',
		'action' => 'get_metadata',
		'slug' => sanitize_text_field($slug),
		'key' => $key
	);

	$url = add_query_arg($request_array, 'https://wpupdateserver.com/v2/');
	
	$result = json_decode(wp_remote_retrieve_body(wp_safe_remote_get($url, $args)));
	
	if (!empty($result->download_url) && strpos($result->download_url, 'https://wpupdateserver.com') !== false) {
		$download_url = esc_url_raw($result->download_url);
	} else {
		echo '<h3>Error</h3>';
		echo '<p>Your theme license key could not be validated. Please contact support@pipdig.zendesk.com if you need support.</p>';
		wp_die();
	}
	
	$temp_file = download_url($download_url, $timeout = 30);
	
	WP_Filesystem();
	$install = unzip_file($temp_file, get_theme_root());
	unlink($temp_file);
	
	if ($install) {
		echo '<h3>Success!</h3>';
		echo '<p>Your theme has been re-installed with the latest version.</p>';
	} else {
		echo '<h3>Error</h3>';
		echo '<p>Your theme license key could not be validated. Please contact support@pipdig.zendesk.com if you need support.</p>';
	}

	wp_die();
}
add_action('wp_ajax_pipdig_p3_theme_installer_ajax', 'pipdig_p3_theme_installer_ajax');
